<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk_SK">
<context>
    <name>DefaultModel</name>
    <message>
        <location filename="../default_model.cpp" line="51"/>
        <source>Command</source>
        <translation>Príkaz</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="52"/>
        <source>DBus call</source>
        <translation>Volanie DBus</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="53"/>
        <source>Client</source>
        <translation>Klient</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="143"/>
        <source>Id</source>
        <translation>Id</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="146"/>
        <source>Shortcut</source>
        <translation>Klávesová skratka</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="149"/>
        <source>Description</source>
        <translation>Popis</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="152"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="155"/>
        <source>Info</source>
        <translation>Informácie</translation>
    </message>
</context>
<context>
    <name>EditActionDialog</name>
    <message>
        <location filename="../edit_action_dialog.ui" line="14"/>
        <source>Edit Action</source>
        <translation>Upraviť akciu</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="31"/>
        <source>&amp;Shortcut:</source>
        <translation>&amp;Klávesová skratka:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="74"/>
        <source>&amp;Description:</source>
        <translation>&amp;Popis:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="87"/>
        <source>&amp;Enabled</source>
        <translation>&amp;Aktívne</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="102"/>
        <source>&amp;Command</source>
        <translation>&amp;Príkaz</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="109"/>
        <source>&amp;DBus message</source>
        <translation>&amp;Správa z DBus</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="118"/>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="164"/>
        <source>Co&amp;mmand:</source>
        <translation>&amp;Príkaz:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="206"/>
        <source>S&amp;ervice:</source>
        <translation>&amp;Služba:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="219"/>
        <source>&amp;Path:</source>
        <translation>&amp;Cesta:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="232"/>
        <source>&amp;Interface:</source>
        <translation>&amp;Rozhranie:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="245"/>
        <source>&amp;Method:</source>
        <translation>&amp;Metóda:</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../main_window.ui" line="14"/>
        <source>Global Actions Manager</source>
        <translation>Globálna sprava akcií</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="24"/>
        <source>Search</source>
        <translation>Hľadať</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="69"/>
        <source>Add ...</source>
        <translation>Pridať...</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="79"/>
        <source>Remove</source>
        <translation>Odstrániť</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="89"/>
        <source>Modify ...</source>
        <translation>Zmeniť...</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="106"/>
        <source>Swap</source>
        <translation>Vymeniť</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="132"/>
        <source>Multiple actions behaviour:</source>
        <translation>Pri viacerých akciách použiť:</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="140"/>
        <source>First</source>
        <comment>globalkeys/config/multipleActions</comment>
        <translation>Prvú</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="145"/>
        <source>Last</source>
        <comment>globalkeys/config/multipleActions</comment>
        <translation>Poslednú</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="150"/>
        <source>None</source>
        <comment>globalkeys/config/multipleActions</comment>
        <translation>Žiadnu</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="155"/>
        <source>All</source>
        <comment>globalkeys/config/multipleActions</comment>
        <translation>Všetky</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="180"/>
        <source>Default</source>
        <translation>Predvolené</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="200"/>
        <source>Close</source>
        <translation>Zatvoriť</translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="191"/>
        <source>Restore Default</source>
        <translation>Vrátiť na predvolené hodnoty</translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="192"/>
        <source>Your defined shortcuts will be removed.
Do you want to proceed?</source>
        <translation>Vami určené klávesové skratky budú odstránené.
Naozaj to chcete?</translation>
    </message>
</context>
</TS>
